#pragma once

#include <stdint.h>
#include <stdbool.h>

struct PlatformWindow;

struct PlatformWindowDesc {
    const char *title = "autosample";
    int32_t width     = 1280;
    int32_t height    = 720;
};

PlatformWindow *platform_create_window(PlatformWindowDesc *desc);
void            platform_destroy_window(PlatformWindow *window);
bool            platform_poll_events(PlatformWindow *window);
void            platform_get_size(PlatformWindow *window, int32_t *w, int32_t *h);
void           *platform_get_native_handle(PlatformWindow *window);
